@@ -1,6 +1,14 @@
-from core import *
+from lice.core import *
 import os
-import unittest
+try:
+    import unittest2 as unittest
+except ImportError:
+    import unittest
+
+
+def collector():
+    start_dir = os.path.abspath(os.path.dirname(__file__))
+    return unittest.defaultTestLoader.discover(start_dir)
 
 
 class TestPaths(unittest.TestCase):
@@ -18,7 +26,8 @@ class TestTemplates(unittest.TestCase):
         for license in LICENSES:
             path = os.path.join(pwd, "template-%s.txt" % license)
             with open(path) as infile:
-                self.assertEqual(infile.read(), load_file_template(path))
+                content = infile.read()
+                self.assertEqual(content, load_file_template(path))
 
     def test_package_template(self):
         pwd = os.path.abspath(os.path.dirname(__file__))
